
# Slot: chemically similar to


holds between one chemical substances and another that it approximates for purposes of scientific study, in virtue of its exhibiting similar features of the studied entity.

URI: [biolink:chemically_similar_to](https://w3id.org/biolink/vocab/chemically_similar_to)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [similar to](similar_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Narrow Mappings:** | | CHEBI:has_parent_hydride |
|  | | CHEBI:has_functional_parent |
|  | | CHEBI:is_conjugate_acid_of |
|  | | CHEBI:is_conjugate_base_of |
|  | | CHEBI:is_enantiomer_of |
|  | | CHEBI:is_tautomer_of |
|  | | NCIT:has_salt_form |

